@@ -51,29 +51,21 @@ namespace vkt {
 
 VkPhysicalDeviceProperties PhysicalDevice::properties() const {
     VkPhysicalDeviceProperties info;
-
     vk::GetPhysicalDeviceProperties(handle(), &info);
-
     return info;
 }
 
 std::vector<VkQueueFamilyProperties> PhysicalDevice::queue_properties() const {
-    std::vector<VkQueueFamilyProperties> info;
-    uint32_t count;
-
-    // Call once with NULL data to receive count
-    vk::GetPhysicalDeviceQueueFamilyProperties(handle(), &count, NULL);
-    info.resize(count);
+    uint32_t count = 0;
+    vk::GetPhysicalDeviceQueueFamilyProperties(handle(), &count, nullptr);
+    std::vector<VkQueueFamilyProperties> info(count);
     vk::GetPhysicalDeviceQueueFamilyProperties(handle(), &count, info.data());
-
     return info;
 }
 
 VkPhysicalDeviceMemoryProperties PhysicalDevice::memory_properties() const {
     VkPhysicalDeviceMemoryProperties info;
-
     vk::GetPhysicalDeviceMemoryProperties(handle(), &info);
-
     return info;
 }
 
@@ -195,7 +187,7 @@ std::vector<VkLayerProperties> PhysicalDevice::layers() const {
     }
 }
 
-QueueCreateInfoArray::QueueCreateInfoArray(const std::vector<VkQueueFamilyProperties> &queue_props)
+QueueCreateInfoArray::QueueCreateInfoArray(const std::vector<VkQueueFamilyProperties> &queue_props, bool all_queue_count)
     : queue_info_(), queue_priorities_() {
     queue_info_.reserve(queue_props.size());
 
@@ -203,7 +195,8 @@ QueueCreateInfoArray::QueueCreateInfoArray(const std::vector<VkQueueFamilyProper
         if (queue_props[i].queueCount > 0) {
             VkDeviceQueueCreateInfo qi = vku::InitStructHelper();
             qi.queueFamilyIndex = i;
-            qi.queueCount = queue_props[i].queueCount;
+            // It is very slow on some drivers (ex Windows NVIDIA) to create all 16/32 queues supported
+            qi.queueCount = all_queue_count ? queue_props[i].queueCount : 1;
             queue_priorities_.emplace_back(qi.queueCount, 0.0f);
             qi.pQueuePriorities = queue_priorities_[i].data();
             queue_info_.push_back(qi);
@@ -219,9 +212,10 @@ void Device::destroy() noexcept {
 
 Device::~Device() noexcept { destroy(); }
 
-void Device::init(std::vector<const char *> &extensions, VkPhysicalDeviceFeatures *features, void *create_device_pnext) {
+void Device::init(std::vector<const char *> &extensions, VkPhysicalDeviceFeatures *features, void *create_device_pnext,
+                  bool all_queue_count) {
     // request all queues
-    QueueCreateInfoArray queue_info(phy_.queue_properties_);
+    QueueCreateInfoArray queue_info(phy_.queue_properties_, all_queue_count);
     for (uint32_t i = 0; i < (uint32_t)phy_.queue_properties_.size(); i++) {
         if (phy_.queue_properties_[i].queueFlags & VK_QUEUE_GRAPHICS_BIT) {
             graphics_queue_node_index_ = i;
@@ -285,8 +279,6 @@ void Device::init_queues(const VkDeviceCreateInfo &info) {
         QueueFamilyQueues &queue_storage = queue_families_[queue_family_i];
         queue_storage.reserve(queue_create_info.queueCount);
         for (uint32_t queue_i = 0; queue_i < queue_create_info.queueCount; ++queue_i) {
-            // TODO: Need to add support for separate MEMMGR and work queues,
-            // including synchronization
             VkQueue queue = VK_NULL_HANDLE;
             vk::GetDeviceQueue(handle(), queue_family_i, queue_i, &queue);
 
@@ -302,7 +294,7 @@ void Device::init_queues(const VkDeviceCreateInfo &info) {
             }
 
             if (queue_family_prop.queueFlags & VK_QUEUE_TRANSFER_BIT) {
-                queues_[DMA].push_back(queue_storage.back().get());
+                queues_[TRANSFER].push_back(queue_storage.back().get());
             }
 
             if (queue_family_prop.queueFlags & VK_QUEUE_SPARSE_BINDING_BIT) {
@@ -311,25 +303,74 @@ void Device::init_queues(const VkDeviceCreateInfo &info) {
         }
     }
 
-    ASSERT_TRUE(!queues_[GRAPHICS].empty() || !queues_[COMPUTE].empty() || !queues_[DMA].empty() || !queues_[SPARSE].empty());
+    ASSERT_TRUE(!queues_[GRAPHICS].empty() || !queues_[COMPUTE].empty() || !queues_[TRANSFER].empty() || !queues_[SPARSE].empty());
 }
 
-const Device::QueueFamilyQueues &Device::queue_family_queues(uint32_t queue_family) const {
+const Device::QueueFamilyQueues &Device::QueuesFromFamily(uint32_t queue_family) const {
     assert(queue_family < queue_families_.size());
     return queue_families_[queue_family];
 }
 
-std::optional<uint32_t> Device::QueueFamilyMatching(VkQueueFlags with, VkQueueFlags without, bool all_bits) {
+std::optional<uint32_t> Device::QueueFamily(VkQueueFlags with, VkQueueFlags without) const {
     for (uint32_t i = 0; i < phy_.queue_properties_.size(); i++) {
-        const auto flags = phy_.queue_properties_[i].queueFlags;
-        const bool matches = all_bits ? (flags & with) == with : (flags & with) != 0;
-        if (matches && ((flags & without) == 0) && (phy_.queue_properties_[i].queueCount > 0)) {
-            return i;
+        if (phy_.queue_properties_[i].queueCount > 0) {
+            const auto flags = phy_.queue_properties_[i].queueFlags;
+            const bool matches = (flags & with) == with;
+            if (matches && ((flags & without) == 0)) {
+                return i;
+            }
         }
     }
     return {};
 }
 
+std::optional<uint32_t> Device::QueueFamilyWithoutCapabilities(VkQueueFlags without) const {
+    for (uint32_t i = 0; i < phy_.queue_properties_.size(); i++) {
+        if (phy_.queue_properties_[i].queueCount > 0) {
+            const auto flags = phy_.queue_properties_[i].queueFlags;
+            if ((flags & without) == 0) {
+                return i;
+            }
+        }
+    }
+    return {};
+}
+
+Queue *Device::QueueWithoutCapabilities(VkQueueFlags without) const {
+    auto family_index = QueueFamilyWithoutCapabilities(without);
+    return family_index.has_value() ? QueuesFromFamily(*family_index)[0].get() : nullptr;
+}
+
+std::optional<uint32_t> Device::ComputeOnlyQueueFamily() const {
+    return QueueFamily(VK_QUEUE_COMPUTE_BIT, VK_QUEUE_GRAPHICS_BIT);
+}
+
+Queue *Device::ComputeOnlyQueue() const {
+    auto family_index = ComputeOnlyQueueFamily();
+    return family_index.has_value() ? QueuesFromFamily(*family_index)[0].get() : nullptr;
+}
+
+std::optional<uint32_t> Device::TransferOnlyQueueFamily() const {
+    return QueueFamily(VK_QUEUE_TRANSFER_BIT, VK_QUEUE_GRAPHICS_BIT | VK_QUEUE_COMPUTE_BIT);
+}
+
+Queue *Device::TransferOnlyQueue() const {
+    auto family_index = TransferOnlyQueueFamily();
+    return family_index.has_value() ? QueuesFromFamily(*family_index)[0].get() : nullptr;
+}
+
+std::optional<uint32_t> Device::NonGraphicsQueueFamily() const {
+    if (auto compute_qfi = ComputeOnlyQueueFamily(); compute_qfi.has_value()) {
+        return compute_qfi;
+    }
+    return TransferOnlyQueueFamily();
+}
+
+Queue *Device::NonGraphicsQueue() const {
+    auto family_index = NonGraphicsQueueFamily();
+    return family_index.has_value() ? QueuesFromFamily(*family_index)[0].get() : nullptr;
+}
+
 bool Device::IsEnabledExtension(const char *extension) const {
     const auto is_x = [&extension](const char *enabled_extension) { return strcmp(extension, enabled_extension) == 0; };
     return std::any_of(enabled_extensions_.begin(), enabled_extensions_.end(), is_x);
@@ -374,9 +415,9 @@ VkFormatFeatureFlags2 Device::FormatFeaturesBuffer(VkFormat format) const {
     }
 }
 
-void Device::wait() const { ASSERT_EQ(VK_SUCCESS, vk::DeviceWaitIdle(handle())); }
+void Device::Wait() const { ASSERT_EQ(VK_SUCCESS, vk::DeviceWaitIdle(handle())); }
 
-VkResult Device::wait(const std::vector<const Fence *> &fences, bool wait_all, uint64_t timeout) {
+VkResult Device::Wait(const std::vector<const Fence *> &fences, bool wait_all, uint64_t timeout) {
     const std::vector<VkFence> fence_handles = MakeVkHandles<VkFence>(fences);
     VkResult err =
         vk::WaitForFences(handle(), static_cast<uint32_t>(fence_handles.size()), fence_handles.data(), wait_all, timeout);
@@ -391,64 +432,314 @@ void Device::update_descriptor_sets(const std::vector<VkWriteDescriptorSet> &wri
                              copies.data());
 }
 
-VkResult Queue::submit(const std::vector<const CommandBuffer *> &cmds, const Fence &fence, bool expect_success) {
+VkResult Queue::Submit(const CommandBuffer &cmd, const Fence &fence) {
+    VkSubmitInfo submit = vku::InitStructHelper();
+    submit.commandBufferCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBuffers = &cmd.handle();
+    VkResult result = vk::QueueSubmit(handle(), 1, &submit, fence.handle());
+    return result;
+}
+
+VkResult Queue::Submit(const vvl::span<CommandBuffer *> &cmds, const Fence &fence) {
     const std::vector<VkCommandBuffer> cmd_handles = MakeVkHandles<VkCommandBuffer>(cmds);
     VkSubmitInfo submit_info = vku::InitStructHelper();
-    submit_info.waitSemaphoreCount = 0;
-    submit_info.pWaitSemaphores = nullptr;
-    submit_info.pWaitDstStageMask = nullptr;
     submit_info.commandBufferCount = static_cast<uint32_t>(cmd_handles.size());
     submit_info.pCommandBuffers = cmd_handles.data();
-    submit_info.signalSemaphoreCount = 0;
-    submit_info.pSignalSemaphores = nullptr;
-
     VkResult result = vk::QueueSubmit(handle(), 1, &submit_info, fence.handle());
-    if (expect_success) {
-        EXPECT_EQ(VK_SUCCESS, result);
+    return result;
+}
+
+VkResult Queue::Submit(const CommandBuffer &cmd, WaitT, const Semaphore &wait_semaphore, VkPipelineStageFlags wait_stage_mask,
+                       const Fence &fence) {
+    VkSubmitInfo submit = vku::InitStructHelper();
+    submit.waitSemaphoreCount = 1;
+    submit.pWaitSemaphores = &wait_semaphore.handle();
+    submit.pWaitDstStageMask = &wait_stage_mask;
+    submit.commandBufferCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBuffers = &cmd.handle();
+    VkResult result = vk::QueueSubmit(handle(), 1, &submit, fence);
+    return result;
+}
+
+VkResult Queue::Submit(const CommandBuffer &cmd, SignalT, const Semaphore &signal_semaphore, const Fence &fence) {
+    VkSubmitInfo submit = vku::InitStructHelper();
+    submit.commandBufferCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBuffers = &cmd.handle();
+    submit.signalSemaphoreCount = 1;
+    submit.pSignalSemaphores = &signal_semaphore.handle();
+    VkResult result = vk::QueueSubmit(handle(), 1, &submit, fence.handle());
+    return result;
+}
+
+VkResult Queue::Submit(const CommandBuffer &cmd, const Semaphore &wait_semaphore, VkPipelineStageFlags wait_stage_mask,
+                       const Semaphore &signal_semaphore, const Fence &fence) {
+    VkSubmitInfo submit = vku::InitStructHelper();
+    submit.waitSemaphoreCount = 1;
+    submit.pWaitSemaphores = &wait_semaphore.handle();
+    submit.pWaitDstStageMask = &wait_stage_mask;
+    submit.commandBufferCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBuffers = &cmd.handle();
+    submit.signalSemaphoreCount = 1;
+    submit.pSignalSemaphores = &signal_semaphore.handle();
+    VkResult result = vk::QueueSubmit(handle(), 1, &submit, fence.handle());
+    return result;
+}
+
+VkResult Queue::SubmitWithTimelineSemaphore(const CommandBuffer &cmd, WaitT, const Semaphore &wait_semaphore, uint64_t wait_value,
+                                            VkPipelineStageFlags wait_stage_mask, const Fence &fence) {
+    VkTimelineSemaphoreSubmitInfo timeline_info = vku::InitStructHelper();
+    timeline_info.waitSemaphoreValueCount = 1;
+    timeline_info.pWaitSemaphoreValues = &wait_value;
+
+    VkSubmitInfo submit = vku::InitStructHelper(&timeline_info);
+    submit.waitSemaphoreCount = 1;
+    submit.pWaitSemaphores = &wait_semaphore.handle();
+    submit.pWaitDstStageMask = &wait_stage_mask;
+    submit.commandBufferCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBuffers = &cmd.handle();
+    VkResult result = vk::QueueSubmit(handle(), 1, &submit, fence.handle());
+    return result;
+}
+
+VkResult Queue::SubmitWithTimelineSemaphore(const CommandBuffer &cmd, SignalT, const Semaphore &signal_semaphore,
+                                            uint64_t signal_value, const Fence &fence) {
+    VkTimelineSemaphoreSubmitInfo timeline_info = vku::InitStructHelper();
+    timeline_info.signalSemaphoreValueCount = 1;
+    timeline_info.pSignalSemaphoreValues = &signal_value;
+
+    VkSubmitInfo submit = vku::InitStructHelper(&timeline_info);
+    submit.commandBufferCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBuffers = &cmd.handle();
+    submit.signalSemaphoreCount = 1;
+    submit.pSignalSemaphores = &signal_semaphore.handle();
+    VkResult result = vk::QueueSubmit(handle(), 1, &submit, fence.handle());
+    return result;
+}
+
+VkResult Queue::SubmitWithTimelineSemaphore(const CommandBuffer &cmd, const Semaphore &wait_semaphore, uint64_t wait_value,
+                                            const Semaphore &signal_semaphore, uint64_t signal_value, const Fence &fence) {
+    VkTimelineSemaphoreSubmitInfo timeline_info = vku::InitStructHelper();
+    timeline_info.waitSemaphoreValueCount = 1;
+    timeline_info.pWaitSemaphoreValues = &wait_value;
+    timeline_info.signalSemaphoreValueCount = 1;
+    timeline_info.pSignalSemaphoreValues = &signal_value;
+
+    const VkPipelineStageFlags wait_stage_mask = VK_PIPELINE_STAGE_ALL_COMMANDS_BIT;
+
+    VkSubmitInfo submit = vku::InitStructHelper(&timeline_info);
+    submit.waitSemaphoreCount = 1;
+    submit.pWaitSemaphores = &wait_semaphore.handle();
+    submit.pWaitDstStageMask = &wait_stage_mask;
+    submit.commandBufferCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBuffers = &cmd.handle();
+    submit.signalSemaphoreCount = 1;
+    submit.pSignalSemaphores = &signal_semaphore.handle();
+    VkResult result = vk::QueueSubmit(handle(), 1, &submit, fence.handle());
+    return result;
+}
+
+VkResult Queue::Submit2(const CommandBuffer &cmd, const Fence &fence, bool use_khr) {
+    VkCommandBufferSubmitInfo cb_info = vku::InitStructHelper();
+    cb_info.commandBuffer = cmd.handle();
+
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.commandBufferInfoCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBufferInfos = &cb_info;
+
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
     }
     return result;
 }
 
-VkResult Queue::submit(const CommandBuffer &cmd, const Fence &fence, bool expect_success) {
-    return submit(std::vector<const CommandBuffer *>(1, &cmd), fence, expect_success);
-}
-
-VkResult Queue::submit(const CommandBuffer &cmd, bool expect_success) {
-    Fence fence;
-    return submit(cmd, fence, expect_success);
-}
-
-VkResult Queue::submit2(const std::vector<const CommandBuffer *> &cmds, const Fence &fence, bool expect_success) {
+VkResult Queue::Submit2(const vvl::span<const CommandBuffer> &cmds, const Fence &fence, bool use_khr) {
     std::vector<VkCommandBufferSubmitInfo> cmd_submit_infos;
+    cmd_submit_infos.reserve(cmds.size());
     for (size_t i = 0; i < cmds.size(); i++) {
         VkCommandBufferSubmitInfo cmd_submit_info = vku::InitStructHelper();
-        cmd_submit_info.deviceMask = 0;
-        cmd_submit_info.commandBuffer = cmds[i]->handle();
+        cmd_submit_info.commandBuffer = cmds[i].handle();
         cmd_submit_infos.push_back(cmd_submit_info);
     }
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.commandBufferInfoCount = static_cast<uint32_t>(cmd_submit_infos.size());
+    submit.pCommandBufferInfos = cmd_submit_infos.data();
 
-    VkSubmitInfo2 submit_info = vku::InitStructHelper();
-    submit_info.flags = 0;
-    submit_info.waitSemaphoreInfoCount = 0;
-    submit_info.pWaitSemaphoreInfos = nullptr;
-    submit_info.signalSemaphoreInfoCount = 0;
-    submit_info.pSignalSemaphoreInfos = nullptr;
-    submit_info.commandBufferInfoCount = static_cast<uint32_t>(cmd_submit_infos.size());
-    submit_info.pCommandBufferInfos = cmd_submit_infos.data();
-
-    // requires synchronization2 to be enabled
-    VkResult result = vk::QueueSubmit2(handle(), 1, &submit_info, fence.handle());
-    if (expect_success) {
-        EXPECT_EQ(VK_SUCCESS, result);
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
     }
     return result;
 }
 
-VkResult Queue::submit2(const CommandBuffer &cmd, const Fence &fence, bool expect_success) {
-    return submit2(std::vector<const CommandBuffer *>(1, &cmd), fence, expect_success);
+VkResult Queue::Submit2(const CommandBuffer &cmd, WaitT, const Semaphore &wait_semaphore, VkPipelineStageFlags2 wait_stage_mask,
+                        const Fence &fence, bool use_khr) {
+    VkCommandBufferSubmitInfo cb_info = vku::InitStructHelper();
+    cb_info.commandBuffer = cmd.handle();
+
+    VkSemaphoreSubmitInfo wait_info = vku::InitStructHelper();
+    wait_info.semaphore = wait_semaphore.handle();
+    wait_info.stageMask = wait_stage_mask;
+
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.waitSemaphoreInfoCount = 1;
+    submit.pWaitSemaphoreInfos = &wait_info;
+    submit.commandBufferInfoCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBufferInfos = &cb_info;
+
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
+    }
+    return result;
 }
 
-VkResult Queue::wait() {
+VkResult Queue::Submit2(const CommandBuffer &cmd, SignalT, const Semaphore &signal_semaphore,
+                        VkPipelineStageFlags2 signal_stage_mask, const Fence &fence, bool use_khr) {
+    VkCommandBufferSubmitInfo cb_info = vku::InitStructHelper();
+    cb_info.commandBuffer = cmd.handle();
+
+    VkSemaphoreSubmitInfo signal_info = vku::InitStructHelper();
+    signal_info.semaphore = signal_semaphore.handle();
+    signal_info.stageMask = signal_stage_mask;
+
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.commandBufferInfoCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBufferInfos = &cb_info;
+    submit.signalSemaphoreInfoCount = 1;
+    submit.pSignalSemaphoreInfos = &signal_info;
+
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
+    }
+    return result;
+}
+
+VkResult Queue::Submit2(const CommandBuffer &cmd, const Semaphore &wait_semaphore, VkPipelineStageFlags2 wait_stage_mask,
+                        const Semaphore &signal_semaphore, VkPipelineStageFlags2 signal_stage_mask, const Fence &fence,
+                        bool use_khr) {
+    VkCommandBufferSubmitInfo cb_info = vku::InitStructHelper();
+    cb_info.commandBuffer = cmd.handle();
+
+    VkSemaphoreSubmitInfo wait_info = vku::InitStructHelper();
+    wait_info.semaphore = wait_semaphore.handle();
+    wait_info.stageMask = wait_stage_mask;
+
+    VkSemaphoreSubmitInfo signal_info = vku::InitStructHelper();
+    signal_info.semaphore = signal_semaphore.handle();
+    signal_info.stageMask = signal_stage_mask;
+
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.waitSemaphoreInfoCount = 1;
+    submit.pWaitSemaphoreInfos = &wait_info;
+    submit.commandBufferInfoCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBufferInfos = &cb_info;
+    submit.signalSemaphoreInfoCount = 1;
+    submit.pSignalSemaphoreInfos = &signal_info;
+
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
+    }
+    return result;
+}
+
+VkResult Queue::Submit2WithTimelineSemaphore(const CommandBuffer &cmd, WaitT tag, const Semaphore &wait_semaphore, uint64_t value,
+                                             VkPipelineStageFlags2 wait_stage_mask, const Fence &fence, bool use_khr) {
+    VkCommandBufferSubmitInfo cb_info = vku::InitStructHelper();
+    cb_info.commandBuffer = cmd.handle();
+
+    VkSemaphoreSubmitInfo wait_info = vku::InitStructHelper();
+    wait_info.semaphore = wait_semaphore.handle();
+    wait_info.value = value;
+    wait_info.stageMask = wait_stage_mask;
+
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.waitSemaphoreInfoCount = 1;
+    submit.pWaitSemaphoreInfos = &wait_info;
+    submit.commandBufferInfoCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBufferInfos = &cb_info;
+
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
+    }
+    return result;
+}
+
+VkResult Queue::Submit2WithTimelineSemaphore(const CommandBuffer &cmd, SignalT tag, const Semaphore &signal_semaphore,
+                                             uint64_t value, VkPipelineStageFlags2 signal_stage_mask, const Fence &fence,
+                                             bool use_khr) {
+    VkCommandBufferSubmitInfo cb_info = vku::InitStructHelper();
+    cb_info.commandBuffer = cmd.handle();
+
+    VkSemaphoreSubmitInfo signal_info = vku::InitStructHelper();
+    signal_info.semaphore = signal_semaphore.handle();
+    signal_info.value = value;
+    signal_info.stageMask = signal_stage_mask;
+
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.commandBufferInfoCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBufferInfos = &cb_info;
+    submit.signalSemaphoreInfoCount = 1;
+    submit.pSignalSemaphoreInfos = &signal_info;
+
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
+    }
+    return result;
+}
+
+VkResult Queue::Submit2WithTimelineSemaphore(const CommandBuffer &cmd, const Semaphore &wait_semaphore, uint64_t wait_value,
+                                             const Semaphore &signal_semaphore, uint64_t signal_value, const Fence &fence,
+                                             bool use_khr) {
+    VkCommandBufferSubmitInfo cb_info = vku::InitStructHelper();
+    cb_info.commandBuffer = cmd.handle();
+
+    VkSemaphoreSubmitInfo wait_info = vku::InitStructHelper();
+    wait_info.semaphore = wait_semaphore.handle();
+    wait_info.value = wait_value;
+    wait_info.stageMask = VK_PIPELINE_STAGE_2_ALL_COMMANDS_BIT;
+
+    VkSemaphoreSubmitInfo signal_info = vku::InitStructHelper();
+    signal_info.semaphore = signal_semaphore.handle();
+    signal_info.value = signal_value;
+    signal_info.stageMask = VK_PIPELINE_STAGE_2_ALL_COMMANDS_BIT;
+
+    VkSubmitInfo2 submit = vku::InitStructHelper();
+    submit.waitSemaphoreInfoCount = 1;
+    submit.pWaitSemaphoreInfos = &wait_info;
+    submit.commandBufferInfoCount = cmd.initialized() ? 1 : 0;
+    submit.pCommandBufferInfos = &cb_info;
+    submit.signalSemaphoreInfoCount = 1;
+    submit.pSignalSemaphoreInfos = &signal_info;
+
+    VkResult result;
+    if (use_khr) {
+        result = vk::QueueSubmit2KHR(handle(), 1, &submit, fence.handle());
+    } else {
+        result = vk::QueueSubmit2(handle(), 1, &submit, fence.handle());
+    }
+    return result;
+}
+
+VkResult Queue::Wait() {
     VkResult result = vk::QueueWaitIdle(handle());
     EXPECT_EQ(VK_SUCCESS, result);
     return result;
@@ -557,10 +848,56 @@ VkResult Fence::import_handle(int fd_handle, VkExternalFenceHandleTypeFlagBits h
 
 NON_DISPATCHABLE_HANDLE_DTOR(Semaphore, vk::DestroySemaphore)
 
+Semaphore::Semaphore(const Device &dev, VkSemaphoreType type, uint64_t initial_value) {
+    if (type == VK_SEMAPHORE_TYPE_BINARY) {
+        init(dev, vku::InitStruct<VkSemaphoreCreateInfo>());
+    } else {
+        VkSemaphoreTypeCreateInfo semaphore_type_ci = vku::InitStructHelper();
+        semaphore_type_ci.semaphoreType = VK_SEMAPHORE_TYPE_TIMELINE_KHR;
+        semaphore_type_ci.initialValue = initial_value;
+        VkSemaphoreCreateInfo semaphore_ci = vku::InitStructHelper(&semaphore_type_ci);
+        init(dev, semaphore_ci);
+    }
+}
+
 void Semaphore::init(const Device &dev, const VkSemaphoreCreateInfo &info) {
     NON_DISPATCHABLE_HANDLE_INIT(vk::CreateSemaphore, dev, &info);
 }
 
+VkResult Semaphore::Wait(uint64_t value, uint64_t timeout) {
+    VkSemaphoreWaitInfo wait_info = vku::InitStructHelper();
+    wait_info.semaphoreCount = 1;
+    wait_info.pSemaphores = &handle();
+    wait_info.pValues = &value;
+    VkResult result = vk::WaitSemaphores(device(), &wait_info, timeout);
+    return result;
+}
+
+VkResult Semaphore::WaitKHR(uint64_t value, uint64_t timeout) {
+    VkSemaphoreWaitInfoKHR wait_info = vku::InitStructHelper();
+    wait_info.semaphoreCount = 1;
+    wait_info.pSemaphores = &handle();
+    wait_info.pValues = &value;
+    VkResult result = vk::WaitSemaphoresKHR(device(), &wait_info, timeout);
+    return result;
+}
+
+VkResult Semaphore::Signal(uint64_t value) {
+    VkSemaphoreSignalInfo signal_info = vku::InitStructHelper();
+    signal_info.semaphore = handle();
+    signal_info.value = value;
+    VkResult result = vk::SignalSemaphore(device(), &signal_info);
+    return result;
+}
+
+VkResult Semaphore::SignalKHR(uint64_t value) {
+    VkSemaphoreSignalInfoKHR signal_info = vku::InitStructHelper();
+    signal_info.semaphore = handle();
+    signal_info.value = value;
+    VkResult result = vk::SignalSemaphoreKHR(device(), &signal_info);
+    return result;
+}
+
 #ifdef VK_USE_PLATFORM_WIN32_KHR
 VkResult Semaphore::export_handle(HANDLE &win32_handle, VkExternalSemaphoreHandleTypeFlagBits handle_type) {
     win32_handle = nullptr;
@@ -954,7 +1291,9 @@ void Image::SetLayout(VkImageAspectFlags aspect, VkImageLayout image_layout) {
     SetLayout(&cmd_buf, aspect, image_layout);
     cmd_buf.end();
 
-    cmd_buf.QueueCommandBuffer();
+    auto graphics_queue = device_->QueuesWithGraphicsCapability()[0];
+    graphics_queue->Submit(cmd_buf);
+    graphics_queue->Wait();
 }
 
 VkImageViewCreateInfo Image::BasicViewCreatInfo(VkImageAspectFlags aspect_mask) const {
@@ -1322,14 +1661,7 @@ void CommandBuffer::init(const Device &dev, const VkCommandBufferAllocateInfo &i
     cmd_pool_ = info.commandPool;
 }
 
-void CommandBuffer::Init(const Device &dev, const CommandPool *pool, VkCommandBufferLevel level, Queue *queue) {
-    if (queue) {
-        m_queue = queue;
-    } else {
-        m_queue = dev.graphics_queues()[0];
-    }
-    assert(m_queue);
-
+void CommandBuffer::Init(const Device &dev, const CommandPool *pool, VkCommandBufferLevel level) {
     auto create_info = CommandBuffer::create_info(pool->handle());
     create_info.level = level;
     init(dev, create_info);
@@ -1391,7 +1723,7 @@ void CommandBuffer::BeginRendering(const VkRenderingInfoKHR &renderingInfo) {
     }
 }
 
-void CommandBuffer::BeginRenderingColor(const VkImageView imageView) {
+void CommandBuffer::BeginRenderingColor(const VkImageView imageView, VkRect2D render_area) {
     VkRenderingAttachmentInfoKHR color_attachment = vku::InitStructHelper();
     color_attachment.imageView = imageView;
     color_attachment.imageLayout = VK_IMAGE_LAYOUT_COLOR_ATTACHMENT_OPTIMAL;
@@ -1400,7 +1732,7 @@ void CommandBuffer::BeginRenderingColor(const VkImageView imageView) {
     renderingInfo.colorAttachmentCount = 1;
     renderingInfo.pColorAttachments = &color_attachment;
     renderingInfo.layerCount = 1;
-    renderingInfo.renderArea = {{0, 0}, {1, 1}};
+    renderingInfo.renderArea = render_area;
 
     BeginRendering(renderingInfo);
 }
@@ -1453,34 +1785,6 @@ void CommandBuffer::EndVideoCoding(const VkVideoEndCodingInfoKHR &endInfo) {
     vkCmdEndVideoCodingKHR(handle(), &endInfo);
 }
 
-void CommandBuffer::QueueCommandBuffer(bool check_success) {
-    Fence null_fence;
-    QueueCommandBuffer(null_fence, check_success);
-}
-
-void CommandBuffer::QueueCommandBuffer(const Fence &fence, bool check_success, bool submit_2) {
-    VkResult err = VK_SUCCESS;
-    (void)err;
-
-    if (submit_2) {
-        err = m_queue->submit2(*this, fence, check_success);
-    } else {
-        err = m_queue->submit(*this, fence, check_success);
-    }
-    if (check_success) {
-        assert(err == VK_SUCCESS);
-    }
-
-    err = m_queue->wait();
-    if (check_success) {
-        assert(err == VK_SUCCESS);
-    }
-
-    // TODO: Determine if we really want this serialization here
-    // Wait for work to finish before cleaning up.
-    vk::DeviceWaitIdle(dev_handle_);
-}
-
 void RenderPass::init(const Device &dev, const VkRenderPassCreateInfo &info) {
     NON_DISPATCHABLE_HANDLE_INIT(vk::CreateRenderPass, dev, &info);
 }
